summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/documentlistview.cpp8
-rw-r--r--src/documentsourceview.cpp16
-rw-r--r--src/entrywidget.cpp4
-rw-r--r--src/kbibtexshell.cpp10
-rw-r--r--src/mergeelements.cpp4
-rw-r--r--src/webquery.cpp4
6 files changed, 23 insertions, 23 deletions
diff --git a/src/documentlistview.cpp b/src/documentlistview.cpp
index e3704de..6d157cf 100644
--- a/src/documentlistview.cpp
+++ b/src/documentlistview.cpp
@@ -135,7 +135,7 @@ namespace KBibTeX
progress->setProgress( i );
if ( i % 43 == 23 )
- kapp->processEvents();
+ tdeApp->processEvents();
}
viewport()->setUpdatesEnabled( update );
@@ -353,12 +353,12 @@ namespace KBibTeX
void DocumentListView::copy()
{
- kapp->clipboard() ->setText( selectedToBibTeXText() );
+ tdeApp->clipboard() ->setText( selectedToBibTeXText() );
}
void DocumentListView::copyReferences()
{
- kapp->clipboard() ->setText( selectedToBibTeXRefs() );
+ tdeApp->clipboard() ->setText( selectedToBibTeXRefs() );
}
void DocumentListView::cut()
@@ -373,7 +373,7 @@ namespace KBibTeX
if ( dlvi == NULL )
dlvi = dynamic_cast<KBibTeX::DocumentListViewItem *>( currentItem() );
- TQString clipboardText = kapp->clipboard() ->text();
+ TQString clipboardText = tdeApp->clipboard() ->text();
return paste( clipboardText, dlvi );
}
diff --git a/src/documentsourceview.cpp b/src/documentsourceview.cpp
index d26ad85..30fb36f 100644
--- a/src/documentsourceview.cpp
+++ b/src/documentsourceview.cpp
@@ -56,7 +56,7 @@ namespace KBibTeX
DocumentSourceView::~DocumentSourceView()
{
- kapp->config() ->sync();
+ tdeApp->config() ->sync();
}
/**
@@ -213,7 +213,7 @@ namespace KBibTeX
bool result = FALSE;
m_progDlg = new KProgressDialog( this, NULL, i18n( "Source View" ), i18n( "Converting BibTeX document to plain text ..." ), true );
m_progDlg->setAllowCancel( false );
- kapp->processEvents();
+ tdeApp->processEvents();
TQBuffer buffer;
buffer.open( IO_WriteOnly );
@@ -229,7 +229,7 @@ namespace KBibTeX
if ( result )
{
- kapp->processEvents();
+ tdeApp->processEvents();
buffer.open( IO_ReadOnly );
TQTextStream in( &buffer );
in.setEncoding( TQTextStream::UnicodeUTF8 );
@@ -238,7 +238,7 @@ namespace KBibTeX
if ( m_editInterface )
{
- kapp->processEvents();
+ tdeApp->processEvents();
// very strange: to set the text, you have to set
// readwrite to TRUE...
m_document->setReadWrite( TRUE );
@@ -249,7 +249,7 @@ namespace KBibTeX
m_bibtexFile = bibtexFile;
}
- kapp->processEvents();
+ tdeApp->processEvents();
delete m_progDlg;
return result;
@@ -314,13 +314,13 @@ namespace KBibTeX
void DocumentSourceView::readConfig()
{
- TDEConfig * config = kapp->config();
+ TDEConfig * config = tdeApp->config();
readConfig( config );
}
void DocumentSourceView::writeConfig()
{
- TDEConfig * config = kapp->config();
+ TDEConfig * config = tdeApp->config();
writeConfig( config );
}
@@ -373,7 +373,7 @@ namespace KBibTeX
{
m_progDlg->progressBar()->setTotalSteps( total );
m_progDlg->progressBar()->setValue( current );
- kapp->processEvents();
+ tdeApp->processEvents();
}
}
diff --git a/src/entrywidget.cpp b/src/entrywidget.cpp
index 46cad7c..7a7aadd 100644
--- a/src/entrywidget.cpp
+++ b/src/entrywidget.cpp
@@ -113,7 +113,7 @@ namespace KBibTeX
delete m_wqa;
- TDEConfig * config = kapp->config();
+ TDEConfig * config = tdeApp->config();
config->setGroup( "EntryWidget" );
saveWindowSize( config );
}
@@ -125,7 +125,7 @@ namespace KBibTeX
if ( ewt != NULL )
ewt->m_fieldLineEditTitle->setFocus();
- TDEConfig * config = kapp->config();
+ TDEConfig * config = tdeApp->config();
config->setGroup( "EntryWidget" );
restoreWindowSize( config );
}
diff --git a/src/mergeelements.cpp b/src/mergeelements.cpp
index 5137f59..9eb2487 100644
--- a/src/mergeelements.cpp
+++ b/src/mergeelements.cpp
@@ -128,7 +128,7 @@ namespace KBibTeX
MergeElements::~MergeElements()
{
- TDEConfig * config = kapp->config();
+ TDEConfig * config = tdeApp->config();
config->setGroup( "MergeElements" );
saveWindowSize( config );
}
@@ -811,7 +811,7 @@ namespace KBibTeX
void MergeElements::slotRestore()
{
tqDebug( "slotRestore" );
- TDEConfig * config = kapp->config();
+ TDEConfig * config = tdeApp->config();
config->setGroup( "MergeElements" );
restoreWindowSize( config );
}
diff --git a/src/webquery.cpp b/src/webquery.cpp
index 959ac44..9365be2 100644
--- a/src/webquery.cpp
+++ b/src/webquery.cpp
@@ -296,14 +296,14 @@ namespace KBibTeX
WebQueryWizard::~WebQueryWizard()
{
- TDEConfig * config = kapp->config();
+ TDEConfig * config = tdeApp->config();
config->setGroup( "WebQueryWizard" );
saveWindowSize( config );
}
void WebQueryWizard::showEvent( TQShowEvent * )
{
- TDEConfig * config = kapp->config();
+ TDEConfig * config = tdeApp->config();
config->setGroup( "WebQueryWizard" );
restoreWindowSize( config );
}
diff --git a/src/kbibtexshell.cpp b/src/kbibtexshell.cpp
index b9b8153..e3195b3 100644
--- a/src/kbibtexshell.cpp
+++ b/src/kbibtexshell.cpp
@@ -74,8 +74,8 @@ KBibTeXShell::KBibTeXShell( TQWidget* parentWidget, const char* name )
// if we couldn't find our Part, we exit since the Shell by
// itself can't do anything useful
KMessageBox::error( this, i18n( "Could not find our part!" ) );
- kapp->quit();
- // we return here, cause kapp->quit() only means "exit the
+ tdeApp->quit();
+ // we return here, cause tdeApp->quit() only means "exit the
// next time we enter the event loop...
return ;
}
@@ -154,13 +154,13 @@ void KBibTeXShell::writeConfig( TDEConfig *config )
void KBibTeXShell::readConfig()
{
- TDEConfig * config = kapp->config();
+ TDEConfig * config = tdeApp->config();
readConfig( config );
}
void KBibTeXShell::writeConfig()
{
- TDEConfig * config = kapp->config();
+ TDEConfig * config = tdeApp->config();
writeConfig( config );
}
@@ -189,7 +189,7 @@ void KBibTeXShell::setupActions()
action = KStdAction::close( this, TQ_SLOT( slotFileClose() ), actionCollection() );
action->setToolTip( i18n( "Close this KBibTeX window" ) );
- // action = KStdAction::quit( kapp, TQ_SLOT( closeAllWindows() ), actionCollection() );
+ // action = KStdAction::quit( tdeApp, TQ_SLOT( closeAllWindows() ), actionCollection() );
// action->setToolTip( i18n( "Close all windows and quit KBibTeX" ) );
m_statusbarAction = KStdAction::showStatusbar( this, TQ_SLOT( optionsShowStatusbar() ), actionCollection() );